@@ -1,21 +1,9 @@
-#
-# This file is part of CPAN-Reporter
-#
-# This software is Copyright (c) 2006 by David Golden.
-#
-# This is free software, licensed under:
-#
-#   The Apache License, Version 2.0, January 2004
-#
-use strict;
 package CPAN::Reporter::PrereqCheck;
-BEGIN {
-  $CPAN::Reporter::PrereqCheck::VERSION = '1.19_04';
-}
-# ABSTRACT: Modulino for prerequisite tests
+use strict;
+use vars qw/$VERSION/;
+$VERSION = '1.03'; 
 
-use ExtUtils::MakeMaker 6.36;
-use File::Spec;
+use ExtUtils::MakeMaker;
 use CPAN::Version;
 
 _run() if ! caller();
@@ -23,20 +11,18 @@ _run() if ! caller();
 sub _run {
     my %saw_mod;
     # read module and prereq string from STDIN
-    local *DEVNULL;
-    open DEVNULL, ">" . File::Spec->devnull;
-    while ( <> ) {
+    while ( <STDIN> ) {
         m/^(\S+)\s+([^\n]*)/;
         my ($mod, $need) = ($1, $2);
         die "Couldn't read module for '$_'" unless $mod;
         $need = 0 if not defined $need;
-
+        
         # only evaluate a module once
         next if $saw_mod{$mod}++;
 
         # get installed version from file with EU::MM
         my($have, $inst_file, $dir, @packpath);
-        if ( $mod eq "perl" ) {
+        if ( $mod eq "perl" ) { 
             $have = $];
         }
         else {
@@ -45,28 +31,22 @@ sub _run {
             if (@packpath == 1 && $packpath[0] eq "readline.pm") {
                 unshift @packpath, "Term", "ReadLine"; # historical reasons
             }
-            INCDIR:
             foreach my $dir (@INC) {
                 my $pmfile = File::Spec->catfile($dir,@packpath);
                 if (-f $pmfile){
                     $inst_file = $pmfile;
-                    last INCDIR;
                 }
             }
-
+            
             # get version from file or else report missing
             if ( defined $inst_file ) {
                 $have = MM->parse_version($inst_file);
                 $have = "0" if ! defined $have || $have eq 'undef';
                 # report broken if it can't be loaded
-                # "select" to try to suppress spurious newlines
-                select DEVNULL; ## no critic
-                if ( ! _try_load( $mod, $have, $inst_file ) ) {
-                    select STDOUT; ## no critic
+                if ( ! eval "require $mod" ) {
                     print "$mod 0 broken\n";
                     next;
                 }
-                select STDOUT; ## no critic
             }
             else {
                 print "$mod 0 n/a\n";
@@ -78,7 +58,7 @@ sub _run {
         my ( @requirements ) = split /\s*,\s*/, $need;
 
         my $passes = 0;
-        RQ:
+        RQ: 
         for my $rq (@requirements) {
             if ($rq =~ s|>=\s*||) {
                 # no-op -- just trimmed string
@@ -88,7 +68,7 @@ sub _run {
                 }
                 next RQ;
             } elsif ($rq =~ s|!=\s*||) {
-                if (CPAN::Version->vcmp($have,$rq)) {
+                if (CPAN::Version->vcmp($have,$rq)) { 
                     $passes++; # didn't match
                 }
                 next RQ;
@@ -114,89 +94,80 @@ sub _run {
     return;
 }
 
-sub _try_load {
-  my ($module, $have, $file) = @_;
-
-  # M::I < 0.95 dies in require, so we can't check if it loads
-  # Instead we just pretend that it works
-  if ( $module eq 'Module::Install' && $have < 0.95 ) {
-    return 1;
-  }
-
-  return eval q{require $file; 1};
-}
-
 1;
 
+__END__
 
+#--------------------------------------------------------------------------#
+# pod documentation 
+#--------------------------------------------------------------------------#
 
-=pod
+=begin wikidoc
 
-=head1 NAME
+= NAME
 
 CPAN::Reporter::PrereqCheck - Modulino for prerequisite tests
 
-=head1 VERSION
+= VERSION
 
-version 1.19_04
+This documentation describes version %%VERSION%%.
 
-=head1 SYNOPSIS
+= SYNOPSIS
 
-  require CPAN::Reporter::PrereqCheck;
-  my $prereq_check = $INC{'CPAN/Reporter/PrereqCheck.pm'};
-  my $result = qx/$perl $prereq_check < $prereq_file/;
+ require CPAN::Reporter::PrereqCheck;
+ my $prereq_check = $INC{'CPAN/Reporter/PrereqCheck.pm'};
+ my $result = qx/$perl $prereq_check < $prereq_file/;
 
-=head1 DESCRIPTION
+= DESCRIPTION
 
 This modulino determines whether a list of prerequisite modules are
 available and, if so, their version number.  It is designed to be run
 as a script in order to provide this information from the perspective of
-a subprocess, just like CPAN::Reporter's invocation of C<<< perl Makefile.PL >>>
+a subprocess, just like CPAN::Reporter's invocation of {perl Makefile.PL}
 and so on.
 
 It reads a module name and prerequisite string pair from each line of input
 and prints out the module name, 0 or 1 depending on whether the prerequisite
 is satisifed, and the installed module version.  If the module is not
-available, it will print "nE<sol>a" for the version.  If the module is available
-but can't be loaded, it will print "broken" for the version.  Modules
+available, it will print "n/a" for the version.  If the module is available
+but can't be loaded, it will print "broken" for the version.  Modules 
 without a version will be treated as being of version "0".
 
-No user serviceable parts are inside.  This modulino is packaged for
+No user serviceable parts are inside.  This modulino is packaged for 
 internal use by CPAN::Reporter.
 
-=head1 BUGS
+= BUGS
 
-Please report any bugs or feature using the CPAN Request Tracker.
-Bugs can be submitted through the web interface at
-L<http://rt.cpan.org/Dist/Display.html?Queue=CPAN-Reporter>
+Please report any bugs or feature using the CPAN Request Tracker.  
+Bugs can be submitted through the web interface at 
+[http://rt.cpan.org/Dist/Display.html?Queue=CPAN-Reporter]
 
 When submitting a bug or request, please include a test-file or a patch to an
 existing test-file that illustrates the bug or desired feature.
 
-=head1 SEE ALSO
+= SEE ALSO
 
-=over
+* [CPAN::Reporter] -- main documentation
 
-=item *
+= AUTHOR
 
-L<CPAN::Reporter> -- main documentation
+David A. Golden (DAGOLDEN)
 
-=back
+= COPYRIGHT AND LICENSE
 
-=head1 AUTHOR
+Copyright (c) 2006, 2007 by David A. Golden
 
-David Golden <dagolden@cpan.org>
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at 
+[http://www.apache.org/licenses/LICENSE-2.0]
 
-=head1 COPYRIGHT AND LICENSE
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
 
-This software is Copyright (c) 2006 by David Golden.
-
-This is free software, licensed under:
-
-  The Apache License, Version 2.0, January 2004
+=end wikidoc
 
 =cut
-
-
-__END__
-
